# Configurence

Configurence is a simple CLI configuration library. It was cowpathed out of [two](https://github.com/jfhbrook/plusdeck) [packages](https://github.com/jfhbrook/crystalfontz).

While this library may be useful to you, it's not necessarily intended for general consumption - at least, not yet. There are plenty of other configuration libraries on PyPI, and your needs (or druthers) are likely different from mine. Even so, it's convenient for me to open source, so here it is.

## Changelog

See [`CHANGELOG.md`](./CHANGELOG.md).

## License

Apache-2.0, see [`LICENSE`](./LICENSE).
